@@ -231,18 +231,31 @@ gboolean dialog(gint32 image_ID, GimpDrawable *drawable, PlugInVals *vals, PlugI
 
 
 
+  GtkWidget *slopes_hbox = gtk_hbox_new (FALSE, 10);
+  gtk_widget_show (slopes_hbox);
+  gtk_container_add (GTK_CONTAINER (main_vbox), slopes_hbox);
 
-  GtkWidget *calcderivs_check = gtk_check_button_new_with_mnemonic(_("Calculate slopes"));
-  gtk_widget_show (calcderivs_check);
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(calcderivs_check), vals->calcderivs);
-  gtk_box_pack_start (GTK_BOX (main_vbox), calcderivs_check, FALSE, FALSE, 6);
+  GtkWidget *slopes_check = gtk_check_button_new_with_mnemonic(_("Calculate slopes"));
+  gtk_widget_show (slopes_check);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(slopes_check), vals->slopes);
+  gtk_box_pack_start (GTK_BOX (slopes_hbox), slopes_check, FALSE, FALSE, 6);
 
-  gtk_widget_set_tooltip_text(calcderivs_check, _(
+  gtk_widget_set_tooltip_text(slopes_check, _(
 	"Whether to calculate a plane for each input pixel. "
 	"This is how much the light intensity near that point increases or decreases, horizontally and vertically. "
 	"This changes the way that the pixel affects nearby interpolated pixels. "
   ));
 
+  GtkWidget *leastsq_check = gtk_check_button_new_with_mnemonic(_("Least squares"));
+  gtk_widget_show (leastsq_check);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(leastsq_check), vals->leastsq);
+  gtk_box_pack_start (GTK_BOX (slopes_hbox), leastsq_check, FALSE, FALSE, 6);
+
+  gtk_widget_set_tooltip_text(leastsq_check, _(
+	"Calculate the least squares plane for each pixel. "
+	"This is a better calculation, but it is slower."
+  ));
+
 
 
 
@@ -265,6 +278,7 @@ gboolean dialog(gint32 image_ID, GimpDrawable *drawable, PlugInVals *vals, PlugI
 	"The size of the window to use for calculating the horizontal and vertical angles, as above."
   ));
 
+#if 0
   GtkWidget *linsymwin_check = gtk_check_button_new_with_mnemonic(_("Symm.win."));
   gtk_widget_show (linsymwin_check);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(linsymwin_check), vals->linsymwin);
@@ -274,13 +288,16 @@ gboolean dialog(gint32 image_ID, GimpDrawable *drawable, PlugInVals *vals, PlugI
 	"Whether to decrease the width or the height of the window near the edges of the image, "
 	"so that it is symmetric around the center pixel."
   ));
+#endif
 
 
 
+#if 0
   GtkWidget *lincenter_check = gtk_check_button_new_with_mnemonic(_("Re-center"));
   gtk_widget_show (lincenter_check);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lincenter_check), vals->lincenter);
   gtk_box_pack_start (GTK_BOX (linwindow_hbox), lincenter_check, FALSE, FALSE, 6);
+#endif
 
 
 
@@ -330,7 +347,7 @@ gboolean dialog(gint32 image_ID, GimpDrawable *drawable, PlugInVals *vals, PlugI
 
 
 
-  /*GtkWidget *linnewlayer_check = gtk_check_button_new_with_mnemonic(_("New layer"));
+  GtkWidget *linnewlayer_check = gtk_check_button_new_with_mnemonic(_("New slopes layer"));
   gtk_widget_show (linnewlayer_check);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(linnewlayer_check), vals->linnewlayer);
   gtk_box_pack_start (GTK_BOX (main_vbox), linnewlayer_check, FALSE, FALSE, 6);
@@ -338,7 +355,7 @@ gboolean dialog(gint32 image_ID, GimpDrawable *drawable, PlugInVals *vals, PlugI
   gtk_widget_set_tooltip_text(linnewlayer_check, _(
 	"Make a new \"grain merge\" layer for the linear result. "
 	"The new layer's alpha channel will be the selection."
-  ));*/
+  ));
 
 
 
@@ -581,13 +598,14 @@ gboolean dialog(gint32 image_ID, GimpDrawable *drawable, PlugInVals *vals, PlugI
 
           vals->multmask = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(multmask));
 
-          vals->calcderivs = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(calcderivs_check));
+          vals->slopes = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(slopes_check));
+          vals->leastsq = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(leastsq_check));
 	  vals->linwindow = gtk_adjustment_get_value(GTK_ADJUSTMENT(linwindow_adj));
-          vals->linsymwin = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(linsymwin_check));
-          vals->lincenter = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lincenter_check));
+          //vals->linsymwin = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(linsymwin_check));
+          //vals->lincenter = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lincenter_check));
 	  vals->linsigma = gtk_adjustment_get_value(GTK_ADJUSTMENT(linsigma_adj));
 	  vals->linkernel = gtk_combo_box_get_active(GTK_COMBO_BOX(linkernel_combo));
-          //vals->linnewlayer = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(linnewlayer_check));
+          vals->linnewlayer = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(linnewlayer_check));
 
           vals->changesel = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(changesel));
 	  vals->lowthres = gtk_adjustment_get_value(GTK_ADJUSTMENT(lowthres_adj));
