@@ -30,13 +30,13 @@ typedef struct {
 	InterpolateKernelType kernel;
 	gboolean newlayer;
 
-	gboolean calcderivs;
+	gboolean slopes;
+	gboolean leastsq;
 	gint linwindow;
-	gboolean lincenter;
 	gboolean linsymwin;
 	gfloat linsigma;
 	InterpolateKernelType linkernel;
-	//gboolean linnewlayer;  // TODO
+	gboolean linnewlayer;
 
 	gboolean changesel;
 	gfloat lowthres;
